@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package Perl::PrereqScanner::Scanner::Moose;
+package Perl::PrereqScanner::Scanner::Moose 1.025;
 # ABSTRACT: scan for Moose sugar indicators of required modules
-$Perl::PrereqScanner::Scanner::Moose::VERSION = '1.022';
+
 use Moose;
 with 'Perl::PrereqScanner::Scanner';
 
@@ -138,7 +138,7 @@ Perl::PrereqScanner::Scanner::Moose - scan for Moose sugar indicators of require
 
 =head1 VERSION
 
-version 1.022
+version 1.025
 
 =head1 DESCRIPTION
 
@@ -156,6 +156,16 @@ L<Moose> roles included with the C<with> keyword
 
 =back
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -166,7 +176,7 @@ Jerome Quelin
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
