@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package Perl::PrereqScanner::Scanner::POE;
+package Perl::PrereqScanner::Scanner::POE 1.025;
 # ABSTRACT: scan for POE components
-$Perl::PrereqScanner::Scanner::POE::VERSION = '1.022';
+
 use Moose;
 with 'Perl::PrereqScanner::Scanner';
 
@@ -47,7 +47,7 @@ Perl::PrereqScanner::Scanner::POE - scan for POE components
 
 =head1 VERSION
 
-version 1.022
+version 1.025
 
 =head1 DESCRIPTION
 
@@ -55,6 +55,16 @@ This scanner will look for POE modules included with C<use POE>
 
   use POE wq(Component::IRC);
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -65,7 +75,7 @@ Jerome Quelin
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
