@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-package Perl::PrereqScanner::Scanner::Perl5 1.024;
+package Perl::PrereqScanner::Scanner::Perl5 1.025;
 # ABSTRACT: scan for core Perl 5 language indicators of required modules
 
 use Moose;
@@ -127,7 +127,7 @@ Perl::PrereqScanner::Scanner::Perl5 - scan for core Perl 5 language indicators o
 
 =head1 VERSION
 
-version 1.024
+version 1.025
 
 =head1 DESCRIPTION
 
@@ -188,7 +188,7 @@ Jerome Quelin
 
 =item *
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
